@@ -25,7 +25,7 @@
  * @author Krista Bennett
  * @author James Blackwell
  * @author Igor Wronsky
- **/
+ */
 
 #include "gnunet_afs_esed2.h"
 #include "platform.h"
@@ -39,87 +39,89 @@ extern char *strptime(const char *s, const char *format, struct tm *tm);
 
 /**
  * Print progess message.
- **/
+ */
 static void printstatus(ProgressStats * stats,
 			void * verboselevel) {
-  if (*(int*)verboselevel == YES)
-    printf("%8u of %8u bytes inserted\r",
+  if (*(int*)verboselevel == YES) {
+    printf(_("%8u of %8u bytes inserted"),
 	   (unsigned int) stats->progress,
 	   (unsigned int) stats->filesize);  
+    printf("\r");
+  }
 }
 
 /**
  * Prints the usage information for this command if the user errs.
  * Aborts the program.
- **/
+ */
 static void printhelp() {
   static Help help[] = {
     { 'b', "builddir", NULL,
-      "build a directory listing all processed files" },
+      gettext_noop("build a directory listing all processed files") },
     HELP_CONFIG,
-    { 'D', "desc", "DESCRIPTION",
-      "set description for all files" },
+    { 'D', "desc", gettext_noop("DESCRIPTION"),
+      gettext_noop("set description for all files") },
     { 'e', "sprev", "FILENAME",
-      "filename of the SBlock of a previous version of the content"
-      " (for namespace insertions only)" },
+      gettext_noop("filename of the SBlock of a previous version of the content"
+		   " (for namespace insertions only)") },
     { 'E', "extract", NULL,
-      "print list of extracted keywords that would be used, but do not perform insertion or indexing" },
+      gettext_noop("print list of extracted keywords that would be used, but do not perform insertion or indexing") },
     { 'f', "name", "NAME",
-      "publish NAME as the name of the file or directory" },
+      gettext_noop("publish NAME as the name of the file or directory") },
     HELP_HELP,
     HELP_HOSTNAME,
     { 'i', "interval", "SECONDS",
-      "set interval for availability of updates to SECONDS"
-      " (for namespace insertions only)" },
+      gettext_noop("set interval for availability of updates to SECONDS"
+		   " (for namespace insertions only)") },
     { 'k', "key", "KEYWORD",
-      "add an additional keyword for the top-level file or directory"
-      " (this option can be specified multiple times)" },
+      gettext_noop("add an additional keyword for the top-level file or directory"
+		   " (this option can be specified multiple times)") },
     { 'K', "global-key", "KEYWORD",
-      "add an additional keyword for all files and directories"
-      " (this option can be specified multiple times)" },   
+      gettext_noop("add an additional keyword for all files and directories"
+		   " (this option can be specified multiple times)") },   
     { 'l', "link", NULL,
-      "if gnunetd is running on the local machine, create a link instead of making a copy in the GNUnet share directory" },
+      gettext_noop("if gnunetd is running on the local machine, create a link instead of making a copy in the GNUnet share directory") },
     HELP_LOGLEVEL,
     { 'm', "mime", "MIMETYPE",
-      "set the mimetype for the file to be MIMETYPE" },
+      gettext_noop("set the mimetype for the file to be MIMETYPE") },
     { 'n', "noindex", NULL,
-      "do not index, perform full insertion (stores entire "
-      "file in encrypted form in GNUnet database)" },
+      gettext_noop("do not index, perform full insertion (stores entire "
+		   "file in encrypted form in GNUnet database)") },
     { 'N', "next", "ID",
-      "specify ID of an updated version to be published in the future"
-      " (for namespace insertions only)" },
+      gettext_noop("specify ID of an updated version to be published in the future"
+		   " (for namespace insertions only)") },
     { 'o', "sout", "FILENAME",
-      "write the created SBlock in plaintext to FILENAME" 
-      " (for namespace insertions only)" },
+      gettext_noop("write the created SBlock in plaintext to FILENAME" 
+		   " (for namespace insertions only)") },
     { 'p', "prio", "PRIORITY",
-      "specify the priority of the content" },
+      gettext_noop("specify the priority of the content") },
     { 'P', "pass", "PASSWORD",
-      "use PASSWORD to decrypt the secret key of the pseudonym" 
-      " (for namespace insertions only)" },
+      gettext_noop("use PASSWORD to decrypt the secret key of the pseudonym" 
+		   " (for namespace insertions only)") },
     { 'R', "recursive", NULL,
-      "process directories recursively" },
+      gettext_noop("process directories recursively") },
     { 's', "pseudonym", "NAME",
-      "publish the files under the pseudonym NAME (place file into namespace)" },
+      gettext_noop("publish the files under the pseudonym NAME (place file into namespace)") },
     { 'S', "sporadic", NULL,
-      "specifies this as an aperiodic but updated publication"
-      " (for namespace insertions only)" },
+      gettext_noop("specifies this as an aperiodic but updated publication"
+		   " (for namespace insertions only)") },
     { 't', "this", "ID",
-      "set the ID of this version of the publication"
-      " (for namespace insertions only)" },
+      gettext_noop("set the ID of this version of the publication"
+		   " (for namespace insertions only)") },
     { 'T', "time", "TIME",
-      "specify creation time for SBlock (see man-page for format)" },
+      gettext_noop("specify creation time for SBlock (see man-page for format)") },
     { 'u', "url", NULL,
-      "print the GNUnet URL of the inserted file(s)" },
+      gettext_noop("print the GNUnet URL of the inserted file(s)") },
     HELP_VERSION,
     HELP_VERBOSE,
     { 'x', "noextraction", NULL,
-      "disable automatic metadata extraction" },
+      gettext_noop("disable automatic metadata extraction") },
     { 'X', "nodirectindex", NULL,
-      "disable generation of RBlocks for keywords extracted from each file" },
+      gettext_noop("disable generation of RBlocks for keywords extracted from each file") },
     HELP_END,
   };
   formatHelp("gnunet-insert [OPTIONS] FILENAME*",
-	     "Make files available to GNUnet for sharing.",
+	     _("Make files available to GNUnet for sharing."),
 	     help);
 }
 
@@ -129,7 +131,7 @@ static void printhelp() {
  * @param filename the name of the file to insert
  * @param fid resulting file identifier for the node
  * @returns OK on success, SYSERR on error
- **/
+ */
 static int doFile(GNUNET_TCP_SOCKET * sock,
 		  char * filename,
 		  FileIdentifier * fid,
@@ -139,16 +141,16 @@ static int doFile(GNUNET_TCP_SOCKET * sock,
 
   cronTime(&startTime);
   if (YES == *verbose)
-    printf("Working on file %s...\n",
+    printf(_("Working on file '%s'.\n"),
 	   filename); 
   top = insertFile(sock,
 		   filename, 
 		   &printstatus,
 		   verbose);
   if (top == NULL) {
-    printf("Error inserting file %s.\n"
-	   "You may want to check whether or not you are out of space.\n"
-	   "Run gnunet-stats | grep \"AFS storage left\" to check.\n",
+    printf(_("Error inserting file '%s'.\n"
+	     "You may want to check whether or not you are out of space.\n"
+	     "Run gnunet-stats | grep \"AFS storage left\" to check.\n"),
 	   filename);
     return SYSERR;
   } else {
@@ -161,7 +163,7 @@ static int doFile(GNUNET_TCP_SOCKET * sock,
 				"PRINTURL",
 				"YES")) {
       char * fstring;
-      fstring = fileIdentifierToString(fid);	
+      fstring = createFileURI(fid);	
       printf("%s\n",
 	     fstring);
       FREE(fstring);
@@ -169,11 +171,11 @@ static int doFile(GNUNET_TCP_SOCKET * sock,
     if (*verbose == YES) {
       char * fstring;
 
-      fstring = fileIdentifierToString(fid);	    
-      printf("File %s successfully indexed -- %s\n",
+      fstring = createFileURI(fid);	    
+      printf(_("File '%s' successfully indexed -- %s\n"),
 	     filename,
 	     fstring);
-      printf("Speed was %8.3f kilobyte per second.\n",
+      printf(_("Speed was %8.3f kilobyte per second.\n"),
 	     (top->filesize/1024.0) / 
 	     (((double)(cronTime(NULL)-startTime)) / (double)cronSECONDS) );
       FREE(fstring);
@@ -228,7 +230,7 @@ static int parseOptions(int argc,
     };    
     c = GNgetopt_long(argc,
 		      argv, 
-		      "vhdc:Ee:L:H:bD:Sf:i:lK:k:m:nN:o:p:P:Rs:t:T:uVxX", 
+		      "bc:dD:e:Ef:hH:i:lL:k:K:m:nN:o:p:P:Rs:St:T:uvVxX", 
 		      long_options, 
 		      &option_index);    
     if (c == -1) 
@@ -283,7 +285,8 @@ static int parseOptions(int argc,
       unsigned int interval;
       if (1 != sscanf(GNoptarg, "%ud", &interval)) {
         LOG(LOG_FAILURE,
-	    "FAILURE: You must pass a positive number to the -i option.\n");
+	    _("You must pass a positive number to the '%s' option.\n"),
+	    "-i");
 	return -1;
       } else
 	setConfigurationInt("GNUNET-INSERT",
@@ -338,7 +341,8 @@ static int parseOptions(int argc,
       
       if (1 != sscanf(GNoptarg, "%ud", &contentPriority)) {
 	LOG(LOG_FAILURE,
-	    "FAILURE: You must pass a number to the -p option.\n");
+	    _("You must pass a number to the '%s' option.\n"),
+	    "-p");
 	return SYSERR;
       }
       setConfigurationInt("GNUNET-INSERT",
@@ -413,7 +417,8 @@ static int parseOptions(int argc,
 					 "NO"));
 #else
       LOG(LOG_INFO,
-      	  "INFO: compiled without libextractor, -x automatic\n");
+      	  "compiled without libextractor, '%s' automatic\n",
+	  "-x");
 #endif
       break;
     case 'X':
@@ -423,19 +428,18 @@ static int parseOptions(int argc,
 					 "NO"));
 #else
       LOG(LOG_INFO,
-      	  "INFO: compiled without libextractor, -X automatic\n");
+      	  "compiled without libextractor, '%s' automatic\n",
+	  "-X");
 #endif
       break;
     default: 
       LOG(LOG_FAILURE,
-	  "FAILURE: Unknown option %c. Aborting.\n"\
-	  "Use --help to get a list of options.\n",
-	  c);
+	  _("Use --help to get a list of options.\n"));
       return SYSERR;
     } /* end of parsing commandline */
   } /* while (1) */
   if (argc == GNoptind) {
-    printf("ERROR: you must specify a list of files to insert.\n");
+    printf(_("You must specify a list of files to insert.\n"));
     return SYSERR;
   }
   if (printAndReturn) {
@@ -443,22 +447,24 @@ static int parseOptions(int argc,
     EXTRACTOR_ExtractorList * l;
     l = getExtractors();
     for (c=GNoptind;c<argc;c++) {
-      printf("Keywords for file %s:\n",
-	     argv[c]);
       EXTRACTOR_KeywordList * list 
 	= EXTRACTOR_getKeywords(l, argv[c]);
+      printf(_("Keywords for file '%s':\n"),
+	     argv[c]);
       EXTRACTOR_printKeywords(stdout,
 			      list);
       EXTRACTOR_freeKeywords(list);
     }
     EXTRACTOR_removeAll(l);
 #else
-    printf("libextractor not used, no keywords will be extracted.\n");
+    printf(_("libextractor not used, no keywords will be extracted.\n"));
 #endif
     return SYSERR;
   }
   setConfigurationStringList(&argv[GNoptind],
 			     argc - GNoptind);
+
+
   return OK;
 }
 
@@ -466,7 +472,7 @@ static int parseOptions(int argc,
  * Insert the given RBlock into GNUnet.
  * @param rb the root node
  * @param keyword the keyword to use
- **/
+ */
 static void insertRBlock(GNUNET_TCP_SOCKET * sock,
 			 RootNode * rb,
 			 char * keyword) {
@@ -475,8 +481,8 @@ static void insertRBlock(GNUNET_TCP_SOCKET * sock,
 				  keyword,
 				  getConfigurationInt("GNUNET-INSERT",
 						      "CONTENT-PRIORITY")))
-    printf("ERROR inserting RootNode. "
-	   "Is gnunetd running and space available?\n");
+    printf(_("Error inserting RBlock. "
+	     "Is gnunetd running and space available?\n"));
 }
 
 
@@ -487,15 +493,14 @@ static void insertRBlock(GNUNET_TCP_SOCKET * sock,
  * @param argc number of arguments from the command line
  * @param argv command line arguments
  * @return return 0 for ok, -1 on error
- **/   
+ */   
 int main(int argc, char ** argv) {
   RootNode * roots;
   int i;
+  int j;
   char * pname;
   Hostkey pseudonym;
   HashCode160 hc;
-  HexName hex1;
-  HexName hex2;
   char ** fileNames;
   char * fileName;
   int fileNameCount;
@@ -506,13 +511,14 @@ int main(int argc, char ** argv) {
   char * shortFN;
 #if USE_LIBEXTRACTOR
   EXTRACTOR_ExtractorList * extractors;
-  char ** keywords;
-  int num_keywords;
 #endif
-  int interval;
+  int interval = 0; /* make gcc happy */
   int skip;
   GNUNET_TCP_SOCKET * sock;
   int verbose;
+  char * timestr;
+  SBlock pb; 	
+  char * prevname;
   
   if (SYSERR == initUtil(argc, argv, &parseOptions)) 
     return 0;
@@ -531,7 +537,7 @@ int main(int argc, char ** argv) {
     pseudonym = readPseudonym(pname,
 			      password);
     if (pseudonym == NULL) {
-      printf("ERROR: could not read pseudonym %s (does not exist or password invalid).\n",
+      printf(_("Could not read pseudonym '%s' (does not exist or password invalid).\n"),
 	     pname);
       FREE(pname);
       FREENONNULL(password);
@@ -540,73 +546,115 @@ int main(int argc, char ** argv) {
     }
     FREENONNULL(password);
     FREE(pname);
-  } else
+  } else {
     pseudonym = NULL;
-  /* fixme: other sanity checks here? */
-
+  }
   fileNameCount = getConfigurationStringList(&fileNames);
 
-  if ( ( testConfigurationString("GNUNET-INSERT",
-				"BUILDDIR",
-				"YES") ||
-	 testConfigurationString("GNUNET-INSERT",
-				 "RECURSIVE",
-				 "YES") ||
-	 (fileNameCount > 1) )
-       && (NULL != getConfigurationString("GNUNET-INSERT",
-					  "FILENAMEROOT") ) )
-    errexit("FATAL: the options -b, -r or multiple file"
-	    " arguments can not be used together with option -f.\n");
-
   if (pseudonym == NULL) {
     if (NULL != getConfigurationString("GNUNET-INSERT",
 				       "NEXTHASH"))
-      errexit("FATAL: Option -N makes no sense without -P\n");
+      errexit(_("Option '%s' makes no sense without option '%s'.\n"),
+	      "-N", "-s");
     if (NULL != getConfigurationString("GNUNET-INSERT",
 				       "THISHASH"))
-      errexit("FATAL: Option -t makes no sense without -P\n");
+      errexit(_("Option '%s' makes no sense without option '%s'.\n"),
+	      "-t", "-s");
     if (NULL != getConfigurationString("GNUNET-INSERT",
 				       "PASSWORD"))
-      errexit("FATAL: Option -P makes no sense without -P\n");
+      errexit(_("Option '%s' makes no sense without option '%s'.\n"),
+	      "-P", "-s");
     if (0 != getConfigurationInt("GNUNET-INSERT",
 				 "INTERVAL"))
-      errexit("FATAL: Option -i makes no sense without -P\n");
+      errexit(_("Option '%s' makes no sense without option '%s'.\n"),
+	      "-i", "-s");
     if (testConfigurationString("GNUNET-INSERT",
 				"SPORADIC",
 				"YES"))
-      errexit("FATAL: Option -S makes no sense without -P\n");
+      errexit(_("Option '%s' makes no sense without option '%s'.\n"),
+	      "-S", "-s");
+  } else { /* have namespace (pseudonym != NULL) */
+    if ( (fileNameCount > 1) && 
+	 (! testConfigurationString("GNUNET-INSERT",
+				    "BUILDDIR",
+				    "YES")) ) 
+      errexit(_("Cannot insert multiple files into namespace in one pass without using directory."));    
+
+    timestr = getConfigurationString("GNUNET-INSERT",
+                    		     "INSERTTIME");
+    if (timestr != NULL) {
+      struct tm t;
+      if ((NULL == strptime(timestr, 
+			    "%j-%m-%Y %R", 
+			    &t))) {
+	LOG_STRERROR(LOG_FATAL, "strptime");
+        errexit(_("Parsing time failed. Use 'DD-MM-YY HH:MM' format.\n"));
+      }
+      FREE(timestr);
+    }
+    
+    prevname = getConfigurationString("GNUNET-INSERT",
+    				      "PREVIOUS_SBLOCK");
+    if (prevname != NULL) {
+      /* options from the previous sblock override */
+      PublicKey pkey;
+      
+      if (sizeof(SBlock) != readFile(prevname,
+      				     sizeof(SBlock),
+				     &pb) ) {
+        errexit(_("SBlock in file '%s' either does not exist or is malformed.\n"),
+		prevname);
+      }
+      /* check that it matches the selected pseudonym */
+      getPublicKey(pseudonym,
+      		   &pkey);
+      if (0 != memcmp(&pkey,
+      	  	      &pb.subspace,
+		      sizeof(PublicKey)))
+        errexit(_("The given SBlock does not belong to the namespace of the selected pseudonym."));
+      
+      if (SYSERR == verifySBlock(&pb)) {
+        errexit(_("Verification of SBlock in file '%s' failed\n"), 
+		prevname);
+      }
+      FREE(prevname);
+      interval = ntohl(pb.updateInterval);
+
+      if (interval == SBLOCK_UPDATE_NONE) 
+	errexit(_("Trying to update nonupdatable SBlock.\n")); 
+    }
   }
 #if USE_LIBEXTRACTOR
-    if (testConfigurationString("GNUNET-INSERT",
-				"EXTRACT-KEYWORDS",
-				"NO") &&
-	testConfigurationString("GNUNET-INSERT",
-				"ADDITIONAL-RBLOCKS",
-				"NO") )
-      printf("WARNING: -X is implied by -x.\n");
+  if (testConfigurationString("GNUNET-INSERT",
+			      "EXTRACT-KEYWORDS",
+			      "NO") &&
+      testConfigurationString("GNUNET-INSERT",
+			      "ADDITIONAL-RBLOCKS",
+			      "NO") )
+    printf(_("Option '%s' is implied by option '%s'.\n"),
+	   "-X", "-x");
+  extractors = getExtractors();
 #endif
   
+  /* fixme: other sanity checks here? */
+
+
   
   /* fundamental init */
   sock = getClientSocket();
   if (sock == NULL)
-    errexit("FATAL: could not connect to gnunetd.\n");
-#if USE_LIBEXTRACTOR
-  extractors = getExtractors();
-#endif
-  mimetype = getConfigurationString("GNUNET-INSERT",
-				    "MIMETYPE");
+    errexit(_("Could not connect to gnunetd.\n"));
 
+  
+  /* first insert all of the top-level files or directories */
   roots = MALLOC(sizeof(RootNode) * fileNameCount);
-  skip = 0;
-  fileName = NULL;
+  skip = 0; /* number of failed insertions... */
   for (i=0;i<fileNameCount;i++) {
-    FREENONNULL(fileName);
     fileName = expandFileName(fileNames[i]);
     r = insertRecursively(sock,
 			  fileName,
 			  &fid,
-			  gloKeywords,
+			  (const char**) gloKeywords,
 			  gloKeywordCnt,
 #if USE_LIBEXTRACTOR
 			  extractors,
@@ -618,38 +666,30 @@ int main(int argc, char ** argv) {
 			  (InsertWrapper)&doFile,
 			  &verbose);    
     if (r != NULL) {
-      memcpy(&roots[i], r, sizeof(RootNode));
+      roots[i-skip] = *r;
       FREE(r);
-    } else
+    } else {
+      FREE(fileNames[i]);
+      for (j=i;j<fileNameCount-1;j++)
+	fileNames[j] = fileNames[j+1];
       skip++;
+    }
+    FREE(fileName);
   }
-  if ( (fileNameCount == 1) &&
-       isDirectory(fileName) ) {
-    FREENONNULL(mimetype);
-    mimetype = STRDUP(GNUNET_DIRECTORY_MIME);
-  }
+  GROW(roots,
+       fileNameCount,
+       fileNameCount - skip);
 
-
-  shortFN = getConfigurationString("GNUNET-INSERT",
-				   "FILENAME");
-  if ( (shortFN == NULL) && (fileName != NULL)) {
-    shortFN = &fileName[strlen(fileName)-1];
-    while (shortFN[-1] != DIR_SEPARATOR)
-      shortFN--;
-    shortFN = STRDUP(shortFN);
-  }
-  fileNameCount -= skip;
-  /* if build directory and > 1 file, build directory
-     and reduce to 1 file */
+  /* if build directory option given and we have more than one file,
+     build directory and reduce to directory containing these files */
   if ( (fileNameCount > 1) &&
        testConfigurationString("GNUNET-INSERT",
 			       "BUILDDIR",
 			       "YES") ) {
-    FREENONNULL(fileName);
     fileName = getConfigurationString("GNUNET-INSERT",
 				      "FILENAMEROOT");
     if (fileName == NULL)
-      fileName = STRDUP("no name specified");
+      fileName = STRDUP(_("no filename specified"));
     i = insertDirectory(sock,
 			fileNameCount,
 			roots,
@@ -657,147 +697,211 @@ int main(int argc, char ** argv) {
 			&fid,
 			&printstatus,
 			&verbose);
+    for (j=0;j<fileNameCount;j++)
+      FREE(fileNames[j]);
     if (i == SYSERR) {
-      skip += fileNameCount;
-      fileNameCount = 0;
-    } else {      
+      /* oops */
+      GROW(fileNames,	   
+	   fileNameCount,
+	   0); 
+      FREE(roots);
+      roots = NULL;
+    } else { 
+      GROW(fileNames,	   
+	   fileNameCount,
+	   1); 
+      fileNames[0] = STRDUP(fileName);
       if (testConfigurationString("GNUNET-INSERT",
 				  "PRINTURL",
 				  "YES")) {
 	char * fstring;
-	fstring = fileIdentifierToString(&fid);	
+	fstring = createFileURI(&fid);	
 	printf("%s\n",
 	       fstring);
 	FREE(fstring);
       }
       if (verbose == YES) {
 	char * fstring;
-	fstring = fileIdentifierToString(&fid);	
-	printf("Directory %s successfully indexed -- %s\n",
+	fstring = createFileURI(&fid);	
+	printf(_("Directory %s successfully indexed -- %s\n"),
 	       fileName,
 	       fstring);
 	FREE(fstring);
-      }
-
+      }    
       description = getConfigurationString("GNUNET-INSERT",
 					   "DESCRIPTION");
       if (description == NULL)
-        description = STRDUP("no description supplied");
+        description = STRDUP("No description supplied.");
       r = buildDirectoryRBlock(sock,
 			       &fid,
 			       fileName,
 			       description,
-			       gloKeywords,
+			       (const char**) gloKeywords,
 			       gloKeywordCnt);
       FREE(description);
+      GROW(roots,
+	   fileNameCount, 
+	   1);
+      roots[0] = *r;
       FREE(r);
-      mimetype = STRDUP(GNUNET_DIRECTORY_MIME);
-      skip = fileNameCount - 1;
-      fileNameCount = 1;
+      FREENONNULL(setConfigurationString("GNUNET-INSERT",
+					 "MIMETYPE",
+					 GNUNET_DIRECTORY_MIME));
     }
+    FREE(fileName);
   }
-  FREE(roots);
 
+
+  /* create and insert RBlocks for all "-k", "-K" and LE keywords */
+  for (i=0;i<fileNameCount;i++) {
 #if USE_LIBEXTRACTOR
-  num_keywords = 0;
-  keywords = NULL;
+    char ** keywords = NULL;
+    int num_keywords = 0;
 #endif
 
-  /* if fileNameCount == 1 and !isDirectory(fileName): run libextractor! */
-  description = getConfigurationString("GNUNET-INSERT",
-				       "DESCRIPTION");
-  if ( (fileNameCount == 1) &&
-       (!isDirectory(fileName)) ) {
-#if USE_LIBEXTRACTOR
-    if (!testConfigurationString("GNUNET-INSERT",
-				 "EXTRACT-KEYWORDS",
-				 "NO")) {
-      extractKeywordsMulti(fileName,
-			   &description,
-			   &mimetype,
-			   &keywords,
-			   &num_keywords,
-			   extractors);
-    }
-#endif
-  }
-  if (mimetype == NULL)
-    mimetype = STRDUP("unknown");
-  if (description == NULL)
-    description = STRDUP("no description supplied");
-  
-  /* if a directory, add mimetype as key unless forbidden */
-  if (strcmp(mimetype,GNUNET_DIRECTORY_MIME)==0 &&
-      !testConfigurationString("GNUNET-INSERT",
-                               "ADDITIONAL-RBLOCKS",
-                               "NO")) {
-      GROW(topKeywords,
-           topKeywordCnt,
-           topKeywordCnt+1);
-      topKeywords[topKeywordCnt-1] = STRDUP(GNUNET_DIRECTORY_MIME);
-  }
+    fileName = expandFileName(fileNames[i]);
 
-  /* if fileNameCount == 1, add RBlocks for all keywords */
-  if ( fileNameCount == 1) {
-    r = createRootNode(&fid,
+    if (! testConfigurationString("GNUNET-INSERT",
+				  "BUILDDIR",
+				  "YES")) {
+      shortFN = getConfigurationString("GNUNET-INSERT",
+				       "FILENAMEROOT");
+      if ( (fileNameCount > 1) &&
+	   (shortFN != NULL) &&
+	   (i == 0) ) {
+	LOG(LOG_WARNING,
+	    _("Filename (option '%s') specified but multiple files given on the command line and not building directory.  Will use the same filename for multiple files."),
+	    "-f");
+      }
+      if ( (shortFN == NULL) && (fileName != NULL)) {
+	shortFN = &fileName[strlen(fileName)-1];
+	while ( (shortFN[-1] != DIR_SEPARATOR) &&
+		(shortFN != fileName) )
+	  shortFN--;
+	shortFN = STRDUP(shortFN);
+      }
+    } else {
+      shortFN = &fileName[strlen(fileName)-1];
+      while ( (shortFN[-1] != DIR_SEPARATOR) &&
+	      (shortFN != fileName) )
+	shortFN--;
+      shortFN = STRDUP(shortFN);      
+    }
+
+    mimetype = getConfigurationString("GNUNET-INSERT",
+				      "MIMETYPE");
+    description = getConfigurationString("GNUNET-INSERT",
+					 "DESCRIPTION");
+#if USE_LIBEXTRACTOR
+    extractKeywordsMulti(fileName,
+			 &description,
+			 &mimetype,
+			 &keywords,
+			 &num_keywords,
+			 extractors);
+#endif   
+    if (mimetype == NULL)
+      mimetype = STRDUP("unknown");
+    if (description == NULL)
+      description = STRDUP("No description supplied.");  
+
+    r = createRootNode(&roots[i].header.fileIdentifier,
 		       description,
 		       shortFN,
 		       mimetype);
-    for (i=0;i<gloKeywordCnt;i++) {
-      insertRBlock(sock, 
-		   r, 
-		   gloKeywords[i]);    
-      printf("Inserting %s (%s, %s) under keyword %s.\n",
-	     shortFN, description, mimetype, gloKeywords[i]);
-    }
-    for (i=0;i<topKeywordCnt;i++) {
+
+    /* if a directory, add mimetype as key unless forbidden */
+    if ( (! testConfigurationString("GNUNET-INSERT",
+				    "ADDITIONAL-RBLOCKS",
+				    "NO")) &&
+	 (0 != strcmp(mimetype, "unknown")) ) {
       insertRBlock(sock,
 		   r,
-		   topKeywords[i]);    
-      printf("Inserting %s (%s, %s) under keyword %s.\n",
-	     shortFN, description, mimetype, topKeywords[i]);
+		   mimetype);
+      printf(_("Inserting file '%s' (%s, %s) under keyword '%s'.\n"),
+	     shortFN, description, mimetype, mimetype);
     }
-#if USE_LIBEXTRACTOR
-    if (! testConfigurationString("GNUNET-INSERT",
-				  "ADDITIONAL-RBLOCKS",
-				  "NO") )
-      for (i=0;i<num_keywords;i++) {
-	insertRBlock(sock,
-		     r,
-		     keywords[i]);    
-	printf("Inserting %s (%s, %s) under keyword %s.\n",
-	       shortFN, description, mimetype, keywords[i]);
-      }
-#endif
-    FREE(r);
-  }
 
-  /* if SBlock and == 1 file, create SBlock */
-  if ( (pseudonym != NULL) &&
-       (fileNameCount == 1) ) {
+#if USE_LIBEXTRACTOR
+    for (j=0;j<num_keywords;j++) {
+      insertRBlock(sock,
+		   r,
+		   keywords[j]);    
+      printf(_("Inserting file '%s' (%s, %s) under keyword '%s'.\n"),
+	     shortFN, description, mimetype, keywords[j]);
+    }
+    for (j=0;j<num_keywords;j++) 
+      FREE(keywords[j]);
+    GROW(keywords, num_keywords, 0);    
+#endif
+    for (j=0;j<gloKeywordCnt;j++) {
+      insertRBlock(sock, 
+		   r, 
+		   gloKeywords[j]);    
+      printf(_("Inserting file '%s' (%s, %s) under keyword '%s'.\n"),
+	     shortFN, description, mimetype, gloKeywords[j]);
+    }
+    for (j=0;j<topKeywordCnt;j++) {
+      insertRBlock(sock,
+		   r,
+		   topKeywords[j]);    
+      printf(_("Inserting file '%s' (%s, %s) under keyword '%s'.\n"),
+	     shortFN, description, mimetype, topKeywords[j]);
+    }
+    FREE(r);
+    FREE(shortFN);
+    FREE(fileName);
+    FREE(mimetype);
+    FREE(description);
+  } /* end top-level processing for all files (for i=0;i<fileNameCount;i++) */
+
+
+  description = getConfigurationString("GNUNET-INSERT",
+				       "DESCRIPTION");
+  if (description == NULL)
+    description = STRDUP("No description supplied.");  
+  
+  mimetype = getConfigurationString("GNUNET-INSERT",
+				    "MIMETYPE");
+  if (mimetype == NULL)
+    mimetype = STRDUP("unknown");
+  
+
+  /* if SBlock requested and just one file left here, create SBlock */
+  if (pseudonym != NULL) {
     HashCode160 thisId;
     HashCode160 nextId;
     char * hx;
-    char * prevname;
     SBlock * sb;
     TIME_T creationTime;
     TIME_T now;
-    char * timestr;
-   
+
+    GNUNET_ASSERT(fileNameCount == 1);
+    shortFN = getConfigurationString("GNUNET-INSERT",
+				     "FILENAME");
+    fileName = expandFileName(fileNames[0]);
+    if ( (shortFN == NULL) && (fileName != NULL)) {
+      shortFN = &fileName[strlen(fileName)-1];
+      while ( (shortFN[-1] != DIR_SEPARATOR) &&
+	      (shortFN != fileName) )
+	shortFN--;
+      shortFN = STRDUP(shortFN);
+    }  
+    FREENONNULL(fileName);
     timestr = getConfigurationString("GNUNET-INSERT",
                     		     "INSERTTIME");
-    if(timestr != NULL) {
+    if (timestr != NULL) {
       struct tm t;
 
-      if((NULL == strptime(timestr, "%j-%m-%Y %R", &t)))
-        errexit("FATAL: parsing time failed. Use \"DAY-MONTHNUMBER-YEAR HOUR:MINUTE\" format\n");
+      /* we can assert here: input was verified earlier! */
+      GNUNET_ASSERT(NULL != strptime(timestr, "%j-%m-%Y %R", &t));
       now = mktime(&t);
       FREE(timestr);
       /* On my system, the printed time is in advance +1h 
 	 to what was specified? -- It is in UTC! */
       timestr = GN_CTIME(&now);
       LOG(LOG_DEBUG, 
-          "DEBUG: read time %s\n", 
+          "Read time '%s'.\n", 
 	  timestr);
       FREE(timestr);
     } else {
@@ -805,39 +909,17 @@ int main(int argc, char ** argv) {
       TIME(&now);
     }
 
+    /* determine update frequency / policy */
     prevname = getConfigurationString("GNUNET-INSERT",
     				      "PREVIOUS_SBLOCK");
-    if(prevname != NULL) {
-      /* options from the previous sblock override */
-      SBlock pb; 	
-      PublicKey pkey;
-      
-      if (sizeof(SBlock) != readFile(prevname,
-      				     sizeof(SBlock),
-				     &pb) ) {
-        errexit("FATAL: SBlock in %s either doesn't exist or is malformed\n",
-		prevname);
-      }
-      /* check that it matches the selected pseudonym */
-      getPublicKey(pseudonym,
-      		   &pkey);
-      if (0 != memcmp(&pkey,
-      	  	      &pb.subspace,
-		      sizeof(PublicKey)))
-        errexit("FATAL: Given SBlock doesn't match the selected pseudonym");
-					   
-      if (SYSERR == verifySBlock(&pb)) {
-        errexit("FATAL: Verification of SBlock in %s failed\n", 
-		prevname);
-      }
-      interval = ntohl(pb.updateInterval);
-
-      /* now, compute CURRENT ID and next ID */
+    if (prevname != NULL) {
+      FREE(prevname);
+      /* now, compute CURRENT ID and next ID from SBlock 'pb' */
       computeIdAtTime(&pb,
       	              now,
 		      &thisId); 
-      if ( (interval != SBLOCK_UPDATE_NONE) &&
-           (interval != SBLOCK_UPDATE_SPORADIC) ) {  
+      /* interval was read and verified earlier... */
+      if (interval != SBLOCK_UPDATE_SPORADIC) {  
         int delta;
 	
         /* periodic update */
@@ -851,22 +933,18 @@ int main(int argc, char ** argv) {
         addHashCodes(&thisId,
 		     &pb.identifierIncrement,
 		     &nextId); /* n = k + inc */
-      } else {
+      } else { /* interval == SBLOCK_UPDATE_SPORADIC */
         creationTime = now;
-        if (interval == SBLOCK_UPDATE_SPORADIC) {
-          LOG(LOG_DEBUG,
-              "DEBUG: sporadic update in sblock...\n");
-          hx = getConfigurationString("GNUNET-INSERT",
-                                      "NEXTHASH");
-          if (hx == NULL) {
-            makeRandomId(&nextId);
-          } else {
-            tryhex2hashOrHashString(hx, &nextId);
-            FREE(hx);
-          }
-        } else {
-          errexit("FATAL: trying to update nonupdatable sblock\n");
-        }
+	LOG(LOG_DEBUG,
+	    "Sporadic update in sblock.\n");
+	hx = getConfigurationString("GNUNET-INSERT",
+				    "NEXTHASH");
+	if (hx == NULL) {
+	  makeRandomId(&nextId);
+	} else {
+	  tryhex2hashOrHashString(hx, &nextId);
+	  FREE(hx);
+	}
       }
     } else {
       /* no previous sblock specified */
@@ -903,6 +981,7 @@ int main(int argc, char ** argv) {
         interval = SBLOCK_UPDATE_SPORADIC;
     }
   
+    /* finally we can create the SBlock */
     sb = buildSBlock(pseudonym,
 		     &fid,
 		     description,
@@ -913,16 +992,13 @@ int main(int argc, char ** argv) {
 		     &thisId,
 		     &nextId);
     freeHostkey(pseudonym);
-    hash2hex(&thisId,
-	     &hex1);
     hash(&sb->subspace,
 	 sizeof(PublicKey),
 	 &hc);
-    hash2hex(&hc,
-	     &hex2);
     if (OK == insertSBlock(sock,
 			   sb)) {
       char * outname;
+      char * uri;
       
       outname = getConfigurationString("GNUNET-INSERT",
       				       "OUTPUT_SBLOCK");
@@ -937,28 +1013,30 @@ int main(int argc, char ** argv) {
 		  sizeof(SBlock),
 		  "600");
 	FREE(outname);
-      }     
-      /* FIXME: until URI is decided for sblocks, stick to SPACE KEY -format */
-      printf("File %s (%s, %s) successfully inserted into namespace under\n"
-	     "  %s %s\n",
-	     shortFN, description, mimetype,
-	     (char*)&hex2,
-	     (char*)&hex1);
-    } else
-      printf("Insertion of file into namespace failed.\n");
+      } 
+      uri = createSubspaceURI(&hc,
+			      &thisId);
+      printf(_("File '%s' (%s, %s) successfully inserted into namespace under\n"
+	       "\t'%s'\n"),
+	     shortFN,
+	     description, 
+	     mimetype,
+	     uri);
+      FREE(uri);
+    } else {
+      printf(_("Insertion of file into namespace failed.\n"));
+    }
     FREE(sb);
+    FREE(shortFN);
   }
 
+  /* shutdown */
 #if USE_LIBEXTRACTOR
-  for (i=0;i<num_keywords;i++) 
-    FREE(keywords[i]);
-  GROW(keywords, num_keywords, 0);
   EXTRACTOR_removeAll(extractors);
 #endif
   for (i=0;i<fileNameCount+skip;i++)
     FREE(fileNames[i]);
   FREE(fileNames);
-  FREENONNULL(fileName);
   for (i=0;i<topKeywordCnt;i++) 
     FREE(topKeywords[i]);
   GROW(topKeywords, topKeywordCnt, 0);
@@ -967,7 +1045,7 @@ int main(int argc, char ** argv) {
   GROW(gloKeywords, gloKeywordCnt, 0);
   FREE(mimetype);
   FREE(description);
-  FREE(shortFN);
+  FREE(roots);
   releaseClientSocket(sock); 
   doneUtil();
   return 0;
