@@ -99,8 +99,8 @@ void  generate_gnunetd_conf (FILE * f) {
  fprintf(f, "%s\n","#");
  fprintf(f, "%s\n","# If you do not specify a HOSTLISTURL, you must copy valid hostkeys to");
  fprintf(f, "%s\n","# data/hosts manually.");
- fprintf(f, "%s\n","# Default: HOSTLISTURL = \"http://www.ovmj.org/GNUnet/download/hostlist http://gnunet.cryss.net/hostlist http://www.woodtick.co.uk/hostlist\"");
- fprintf(f, "%s\n","HOSTLISTURL = \"http://www.ovmj.org/GNUnet/download/hostlist http://gnunet.cryss.net/hostlist http://www.woodtick.co.uk/hostlist\"");
+ fprintf(f, "%s\n","# Default: HOSTLISTURL = \"http://www.ovmj.org/GNUnet/download/hostlist http://www.woodtick.co.uk/hostlist\"");
+ fprintf(f, "%s\n","HOSTLISTURL = \"http://www.ovmj.org/GNUnet/download/hostlist http://gnunet.wensley.org.uk/hostlist\"");
  fprintf(f, "%s\n","");
  fprintf(f, "%s\n","# If you have to use a proxy for outbound HTTP connections,");
  fprintf(f, "%s\n","# specify the proxy configuration here.  Default is no proxy.");
@@ -134,7 +134,7 @@ void  generate_gnunetd_conf (FILE * f) {
  fprintf(f, "%s\n","# tcp6, udp6 and the special 'nat' service.");
  fprintf(f, "%s\n","#");
  fprintf(f, "%s\n","# Loading the 'nat' and 'tcp' modules is required for peers behind NAT");
- fprintf(f, "%s\n","# boxes that can not directly be reached from the outside.  Peers that");
+ fprintf(f, "%s\n","# boxes that cannot directly be reached from the outside.  Peers that");
  fprintf(f, "%s\n","# are NOT behind a NAT box and that want to *allow* peers that ARE");
  fprintf(f, "%s\n","# behind a NAT box to connect must ALSO load the 'nat' module.  Note");
  fprintf(f, "%s\n","# that the actual transfer will always be via tcp initiated by the peer");
@@ -350,10 +350,10 @@ void  generate_gnunetd_conf (FILE * f) {
  fprintf(f, "%s\n","# (if you can configure the NAT box to allow");
  fprintf(f, "%s\n","# direct connections from other peers, set this");
  fprintf(f, "%s\n","# to NO).  Set this only to YES if other peers");
- fprintf(f, "%s\n","# can not contact you directly via TCP or UDP.");
- fprintf(f, "%s\n","# If you set this to NO, you should also set the");
- fprintf(f, "%s\n","# TCP and UDP port to '0' to indicate that you");
- fprintf(f, "%s\n","# can not accept inbound connections.");
+ fprintf(f, "%s\n","# cannot contact you directly via TCP or UDP.");
+ fprintf(f, "%s\n","# If you set this to YES, you should also set the");
+ fprintf(f, "%s\n","# TCP port to '0' and disable UDP to indicate that you");
+ fprintf(f, "%s\n","# cannot accept inbound connections.");
  fprintf(f, "%s\n","#");
  fprintf(f, "%s\n","# Default: NO");
  fprintf(f, "%s\n","LIMITED = NO");
@@ -454,7 +454,7 @@ void  generate_gnunetd_conf (FILE * f) {
  fprintf(f, "%s\n","DISKQUOTA 	= 1024");
  fprintf(f, "%s\n","");
  fprintf(f, "%s\n","# Which database type should be used for content? Valid types are");
- fprintf(f, "%s\n","# \"gdbm\", \"mysql\", \"tdb\" and \"directory\". Specified type must have");
+ fprintf(f, "%s\n","# \"gdbm\", \"mysql\", \"tdb\", \"sqlite\" and \"directory\". Specified type must have");
  fprintf(f, "%s\n","# been available at compile time. \"directory\" is available on all");
  fprintf(f, "%s\n","# systems but typically uses more space and can also be slower.  mysql");
  fprintf(f, "%s\n","# will require some additional setup of the database.");
@@ -575,6 +575,24 @@ void  generate_gnunetd_conf (FILE * f) {
  fprintf(f, "%s\n","# Indexing quota.  Default is 8192.");
  fprintf(f, "%s\n","INDEX-QUOTA = 8192");
  fprintf(f, "%s\n","");
+ fprintf(f, "%s\n","#######################################");
+ fprintf(f, "%s\n","# Experimental GDBM options");
+ fprintf(f, "%s\n","#######################################");
+ fprintf(f, "%s\n","");
+ fprintf(f, "%s\n","[GDBM]");
+ fprintf(f, "%s\n","");
+ fprintf(f, "%s\n","# Use experimental settings for managing");
+ fprintf(f, "%s\n","# free blocks in gdbm.  Default is YES!");
+ fprintf(f, "%s\n","EXPERIMENTAL = YES");
+ fprintf(f, "%s\n","");
+ fprintf(f, "%s\n","# This option allows avoiding gdbm database reorganization");
+ fprintf(f, "%s\n","# on startup.  It should definitely only be used together");
+ fprintf(f, "%s\n","# with the experimental gdbm free blocks option.  Nevertheless,");
+ fprintf(f, "%s\n","# the option has not been tested extensively yet, so to be");
+ fprintf(f, "%s\n","# safe it should be set to 'YES' (do reorganize).  Default");
+ fprintf(f, "%s\n","# is 'YES'.");
+ fprintf(f, "%s\n","REORGANIZE = YES");
+ fprintf(f, "%s\n","");
  fprintf(f, "%s\n","");
  fprintf(f, "%s\n","#######################################");
  fprintf(f, "%s\n","# TESTBED (experimental!)");
@@ -600,4 +618,22 @@ void  generate_gnunetd_conf (FILE * f) {
  fprintf(f, "%s\n","# will try to make a direct TCP connection to the");
  fprintf(f, "%s\n","# application port (default: 2087).");
  fprintf(f, "%s\n","# LOGIN = ");
+ fprintf(f, "%s\n","");
+ fprintf(f, "%s\n","");
+ fprintf(f, "%s\n","########################################");
+ fprintf(f, "%s\n","# DHT (experimental)");
+ fprintf(f, "%s\n","########################################");
+ fprintf(f, "%s\n","");
+ fprintf(f, "%s\n","[DHT]");
+ fprintf(f, "%s\n","");
+ fprintf(f, "%s\n","# Number of buckets to use (determines memory requirements)");
+ fprintf(f, "%s\n","# Default (and maximum) is 160.");
+ fprintf(f, "%s\n","BUCKETCOUNT = 160");
+ fprintf(f, "%s\n","");
+ fprintf(f, "%s\n","# Amount of memory (in bytes) to use for the master table");
+ fprintf(f, "%s\n","# (table that caches table-to-peer mappings).");
+ fprintf(f, "%s\n","# Default is 65536.");
+ fprintf(f, "%s\n","MASTER-TABLE-SIZE = 65536");
+ fprintf(f, "%s\n","");
+ fprintf(f, "%s\n","");
 }
